package com.example.osnov_android

import androidx.compose.ui.test.assertIsDisplayed
import androidx.compose.ui.test.junit4.createComposeRule
import androidx.compose.ui.test.onNodeWithText
import androidx.navigation.compose.rememberNavController
import androidx.test.ext.junit.runners.AndroidJUnit4
import androidx.test.platform.app.InstrumentationRegistry
import com.example.osnov_android.views.Faq
import com.example.osnov_android.views.Profile
import com.example.osnov_android.views.SignIn
import com.example.osnov_android.views.SignUp
import com.example.osnov_android.views.Start
import org.junit.Assert.assertEquals
import org.junit.Rule
import org.junit.Test
import org.junit.runner.RunWith
import org.junit.Assert.assertTrue

@RunWith(AndroidJUnit4::class)
class ExampleInstrumentedTest {
    @get:Rule
    val composeTestRule = createComposeRule()
    @Test
    fun useAppContext() {
        // Context of the app under test.
        val appContext = InstrumentationRegistry.getInstrumentation().targetContext
        assertEquals("com.example.osnov_android", appContext.packageName)
    }

    /*
        Проверка отображения экрана регистрации
     */

    @Test
    fun SignUpDisplayed()
    {
        composeTestRule.setContent { SignUp(rememberNavController(), MainActivityViewModel())}

        composeTestRule.onNodeWithText("Назад").assertIsDisplayed()
        composeTestRule.onNodeWithText("Пароль").assertIsDisplayed()
        composeTestRule.onNodeWithText("Имя").assertIsDisplayed()
        composeTestRule.onNodeWithText("FOOD EXPERT").assertIsDisplayed()
        composeTestRule.onNodeWithText("Email").assertIsDisplayed()
        composeTestRule.onNodeWithText("Повторите пароль").assertIsDisplayed()
    }

    /*
        Проверка отображения начального экрана
     */

    @Test
    fun StartPageDisplayed()
    {
        composeTestRule.setContent { Start(rememberNavController())}

        composeTestRule.onNodeWithText("Добро пожаловать!").assertIsDisplayed()
        composeTestRule.onNodeWithText("Мы рады что вы с нами!").assertIsDisplayed()
        composeTestRule.onNodeWithText("Вход").assertIsDisplayed()
        composeTestRule.onNodeWithText("Регистрация").assertIsDisplayed()
        composeTestRule.onNodeWithText("FOOD EXPERT").assertIsDisplayed()
    }

    /*
        Проверка отображения экрана авторизации
     */

    @Test
    fun SignInDisplayed()
    {
        composeTestRule.setContent { SignIn(rememberNavController(), MainActivityViewModel()) }

        composeTestRule.onNodeWithText("С возвращением!").assertIsDisplayed()
        composeTestRule.onNodeWithText("Email").assertIsDisplayed()
        composeTestRule.onNodeWithText("Введите пароль").assertIsDisplayed()
        composeTestRule.onNodeWithText("Вход").assertIsDisplayed()
        composeTestRule.onNodeWithText("Назад").assertIsDisplayed()
        composeTestRule.onNodeWithText("FOOD EXPERT").assertIsDisplayed()
    }

    /*
        Проверка отображения экрана помощи
     */

    @Test
    fun FaqDisplayed() {
        composeTestRule.setContent { Faq() }

        composeTestRule.onNodeWithText("Часто задаваемые вопросы").assertIsDisplayed()
        composeTestRule.onNodeWithText("Как восстановить пароль?").assertIsDisplayed()
        composeTestRule.onNodeWithText("Как изменить настройки профиля?").assertIsDisplayed()
        composeTestRule.onNodeWithText("Как связаться с поддержкой?").assertIsDisplayed()
        composeTestRule.onNodeWithText("Остались вопросы?").assertIsDisplayed()
    }

    /*
        Проверка отображения страницы профиля, из самой страницы закоментировал все элементы, которые берутся из viewmodel
     */

    @Test
    fun ProfileDisplayed() {
        composeTestRule.setContent { Profile(rememberNavController()) }

        composeTestRule.onNodeWithText("ПРОФИЛЬ").assertIsDisplayed()
        composeTestRule.onNodeWithText("Изменить").assertIsDisplayed()
        composeTestRule.onNodeWithText("Мои посты:").assertIsDisplayed()
    }

}