package com.example.osnov_android

import android.util.Log
import androidx.compose.runtime.State
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.osnov_android.components.Constants
import com.example.osnov_android.models.Dishes
import com.example.osnov_android.models.DishesBlog
import com.example.osnov_android.models.UserState
import com.example.osnov_android.models.Users
import io.github.jan.supabase.auth.auth
import io.github.jan.supabase.auth.providers.builtin.Email
import io.github.jan.supabase.postgrest.from
import kotlinx.coroutines.launch


class MainActivityViewModel : ViewModel() {
    val _userState = mutableStateOf<UserState>(UserState.Loading)
    val userState: State<UserState> = _userState // переменные успешного и неуспешного выполнения функции

    private val _users = mutableStateOf(listOf<Users>()) // ->
    val users: State<List<Users>> = _users // переменные для авторизации и регистрации нового пользователя

    private val _cookings = mutableStateOf(listOf<Dishes>()) // ->
    val cookings: State<List<Dishes>> = _cookings // Переменная для вывода всех элементов из таблицы Dishes
    var cooking by mutableStateOf<Dishes?>(null) // Информация для вывода информации элемента из таблицы Dishes
    private val _user = mutableStateOf(listOf<Users>()) // ->
    val user: State<List<Users>> = _user // переменные для вывода информации о пользователе
    private val _cookingsblog = mutableStateOf(listOf<DishesBlog>()) // ->
    val cookingsblog: State<List<DishesBlog>> = _cookingsblog // переменные для вывода всех постов
    var cookingblog by mutableStateOf<DishesBlog?>(null) // переменная для вывода информации о посте

    private val _mycookings = mutableStateOf(listOf<DishesBlog>()) // ->
    val mycookings: State<List<DishesBlog>> = _mycookings // переменные для вывода постов пользователя

    public val email = mutableStateOf("")
    public val password = mutableStateOf("")

    fun MyCookings() // Функция для вывода постов авторизированного пользователя в профиль
    {
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading
                Log.d("Mycookings", "${user.value.last().id} ${DishesBlog::id_user}")
                _mycookings.value = Constants.supabase.from("DishesBlog").select() {
                    filter {
                        DishesBlog::id_user eq user.value.last().id
                    }
                }.decodeList()
            }
            catch (e:Exception)
            {
                _userState.value = UserState.Error("${e.message}")
            }
        }
    }

    fun SignIn(emailUser: String, userPassword: String) { // Функция для авторизации пользователя
        viewModelScope.launch {
            try {
                email.value = emailUser
                password.value = userPassword
                Log.d("начало", "${emailUser} ${userPassword}")
                _userState.value = UserState.Loading
                Constants.supabase.auth.signInWith(Email) {
                    email = emailUser
                    password = userPassword
                }
                _users.value = Constants.supabase.from("Users").select {
                    filter {
                        Users::password eq Constants.supabase.auth.currentUserOrNull()!!.id
                    }
                }.decodeList()
                Log.d("Mytag", "${users.value.last().id_role}")
                Log.d("Конец", "закончили")
                _userState.value = UserState.Success("Signin is suc!")
            } catch (e: Exception) {
                _userState.value = UserState.Error("Error: ${e.message}")
            }
        }
    }

    fun SignUp(emailUser: String,nameUsers: String, gender: Int, passwordUsers: String) { // Функция для регистрации пользователя
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading
                Constants.supabase.auth.signUpWith(Email)
                {
                    email = emailUser
                    password = passwordUsers
                }
                Constants.supabase.from("Users").insert(
                    Users(
                        login = emailUser,
                        name = nameUsers,
                        password = Constants.supabase.auth.currentUserOrNull()!!.id,
                        id_role = 2,
                        id_gender = gender,
                        image = "https://unmeiceifhurzmiokboh.supabase.co/storage/v1/object/public/Users_ava/zaglushka.jpg"
                    )
                )
                Log.d("добавили", "Пользователь добавлен")
                _userState.value = UserState.Success("SignUp in suc!")
            } catch (e: Exception) {
                _userState.value = UserState.Error("Error: ${e.message}")
            }
        }
    }

    fun AddDishesBlog(name:String, descr: String,gotov: String) // Функция для добавления нового поста во вкладку Blog
    {
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading

                _user.value = Constants.supabase.from("Users").select {
                    filter {
                        Users::password eq Constants.supabase.auth.currentUserOrNull()!!.id
                    }
                }.decodeList<Users>()
                Log.d("my_tag", "Профиль найден")

                Log.d("my tag blog", "Поехали")
                Log.d("my tag blog", "${name} ${descr} ${gotov}")

                Constants.supabase.from("DishesBlog").insert(
                    DishesBlog(
                        Name = name,
                        Image = "https://unmeiceifhurzmiokboh.supabase.co/storage/v1/object/public/Dishes_blog/no-foto-2.jpg",
                        id_user = user.value.last().id.toInt(),
                        Description = descr,
                        Gotovka = gotov
                    )
                )
                Log.d("my tag blog", "Данные добалены")
                _userState.value = UserState.Success("Добавление успешно")
            }
            catch (e: Exception)
            {
                _userState.value = UserState.Error(e.message!!)
            }
        }
    }


    fun giveBlog(cookingblog: DishesBlog) // Функция для поска поста в таблице для вывода информации
    {
        this.cookingblog = cookingblog
    }

    fun Updatecookingblog(name:String, descr:String, gotov:String, id:Int) { // Функция для обновления данных поста(для роли админа)
        viewModelScope.launch {

            try {
            _userState.value = UserState.Loading
            Constants.supabase.from("DishesBlog").update(
                {
                    set("Name",  name)
                    set("Description",  descr)
                    set("Gotovka",  gotov)
                }
            ) {
                filter {
                    DishesBlog::id eq id
                }
            }
            Log.d("my_tag_blog", "Данные обновлены")
            _userState.value = UserState.Success("Данные обновлены")
            allDishesBlog()

        } catch (e: Exception) {
            _userState.value = UserState.Error(e.message!!)
            Log.e("error", e.message!!)
        }
    }
    }

    fun UpdateDish(name:String, descr:String, gotov:String, id:Int) // Функция для обновления данных вкладки Gotovka(для роли админа)
    {
        viewModelScope.launch {

            try {
                _userState.value = UserState.Loading
                Constants.supabase.from("DishesBlog").update(
                    {
                        set("Name",  name)
                        set("Description",  descr)
                        set("Gotovka",  gotov)
                    }
                ) {
                    filter {
                        Dishes::id eq id
                    }
                }
                Log.d("my_tag_blog", "Данные обновлены")
                _userState.value = UserState.Success("Данные обновлены")
                allDishesBlog()

            } catch (e: Exception) {
                _userState.value = UserState.Error(e.message!!)
                Log.e("error", e.message!!)
            }
        }
    }
    fun allDishes() { // Функция для вывода всех элементов из таблицы Dishes
        viewModelScope.launch {
            try {
                Log.d("начали еда", "Поехали еда")
                _userState.value = UserState.Loading

                _cookings.value = Constants.supabase.from("Dishes").select().decodeList()

                _userState.value =
                    UserState.Success("select dishes suc!")
                Log.d("my_tag", "select dishes suc!")
            } catch (e: Exception) {
                _userState.value = UserState.Error("Error:  ${e.message}")
                Log.e("error", e.message!!)
            }
        }
    }

    fun allDishesBlog() // Функция для вывода всех элементов из таблицы DishesBlog
    {
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading
                _cookingsblog.value = Constants.supabase.from("DishesBlog").select().decodeList<DishesBlog>()
                Log.d("blog_tag","Ехала еда блог")
                _userState.value = UserState.Success("Блог успешно выбран")
                Log.d("blog_tag", "данные с блога suc!")
            }
            catch (e: Exception)
            {
                _userState.value = UserState.Error(e.message!!)
            }

        }
    }

    fun profileData() { // Функция для поска авторизированного пользователя для последующего вывода информации о нем
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading
                _user.value = Constants.supabase.from("Users").select {
                    filter {
                        Users::password eq Constants.supabase.auth.currentUserOrNull()!!.id
                    }
                }.decodeList<Users>()
                Log.d("my_tag", "Профиль найден")
                _userState.value = UserState.Success("Профиль найден")

            } catch (e: Exception) {
                _userState.value = UserState.Error("Профиль не найден")
                Log.e("error", e.message!!)
            }
        }
    }

    fun updateUser(name: String, gender: Int) { // Функция для обновления данных пользователя
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading
                Constants.supabase.from("Users").update(
                    {
                        Users::name setTo name
                        Users::id_gender setTo gender
                    }
                ) {
                    filter {
                        Users::password eq Constants.supabase.auth.currentUserOrNull()!!.id
                    }
                }
                Log.d("my_tag", "Данные обновлены")
                _userState.value = UserState.Success("Данные обновлены")

            } catch (e: Exception) {
                _userState.value = UserState.Error(e.message!!)
                Log.e("error", e.message!!)
            }
        }

    }

    fun giveCooking(cooking: Dishes) { // Функция для поска элемента в таблице Dishes для вывода информации
        this.cooking = cooking
    }

    fun deleteCooking(id: Int) // Функция для удаления элемента из таблицы Dishes(для роли админа)
    {
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading

                Constants.supabase.from("Dishes").delete{
                    filter {
                        Dishes::id eq id
                    }
                }
                allDishes()
                _userState.value = UserState.Success("the dish has deleted suc!")
                Log.d("My tag dish", "deleted")
            }
            catch (e: Exception)
            {
                _userState.value = UserState.Error(e.message!!)
            }
        }
    }

    fun deleteCookingBlog(id: Int) // Функция для удаления элемента из таблицы DishesBlog(для роли админа)
    {
        viewModelScope.launch {
            try {
                _userState.value = UserState.Loading

                Constants.supabase.from("DishesBlog").delete{
                    filter {
                        DishesBlog::id eq id
                    }
                }
                allDishes()
                _userState.value = UserState.Success("the dish has deleted suc!")
                Log.d("My tag dish", "deleted")
            }
            catch (e: Exception)
            {
                _userState.value = UserState.Error(e.message!!)
            }
        }
    }

}