package com.example.osnov_android.views

import android.widget.Toast
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonColors
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Text
import androidx.compose.material3.TextFieldDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.navigation.NavController
import com.example.osnov_android.MainActivityViewModel
import com.example.osnov_android.models.UserState

@Composable
fun BlogAddItem(viewModel: MainActivityViewModel, navController: NavController)
{

    val background = Color(0xFF1B1A20)
    val flag = remember { mutableStateOf(false) }
    val userState by viewModel.userState
    val context = LocalContext.current
    val name = remember { mutableStateOf("") }
    val decr = remember { mutableStateOf("") }
    val gotov = remember { mutableStateOf("") }

    Column(
        modifier = Modifier
            .fillMaxSize()
            .background(background)
            .padding(top = 50.dp),
        horizontalAlignment = Alignment.CenterHorizontally
    ) {
        Text(
            text = "БЛОГ",
            fontWeight = FontWeight.Light,
            fontSize = 24.sp,
            color = Color(0xFFFFFFFF),
            letterSpacing = 10.sp
        )
        Spacer(Modifier.height(30.dp))

        Spacer(Modifier.width(60.dp))
        Text(text = "Название", modifier = Modifier.padding(top = 30.dp), color = Color.White)
        OutlinedTextField(
            value = name.value,
            onValueChange = { name.value = it },
            textStyle = TextStyle(
                color = Color.Black,
                fontSize = 15.sp
            ),
            colors = TextFieldDefaults.colors(
                focusedContainerColor = Color(0XFFF5F5F9),
                focusedIndicatorColor = Color(0xFFEBEBEB),
                focusedTextColor = background,
                disabledIndicatorColor = Color.Transparent,
                unfocusedIndicatorColor = Color.Transparent,
                cursorColor = background,
            ),
            modifier = Modifier
                .fillMaxWidth(0.7f)
                .width(width = 316.dp)
        )
        Spacer(Modifier.width(60.dp))
        Text("Описание", modifier = Modifier.padding(top = 30.dp), color = Color.White)
        OutlinedTextField(
            value = decr.value,
            onValueChange = { decr.value = it },
            textStyle = TextStyle(
                color = Color.Black,
                fontSize = 15.sp
            ),
            colors = TextFieldDefaults.colors(
                focusedContainerColor = Color(0XFFF5F5F9),
                focusedIndicatorColor = Color(0xFFEBEBEB),
                focusedTextColor = background,
                disabledIndicatorColor = Color.Transparent,
                unfocusedIndicatorColor = Color.Transparent,
                cursorColor = background,
            ),
            modifier = Modifier
                .fillMaxWidth(0.7f)
                .width(width = 316.dp)
        )
        Spacer(Modifier.width(100.dp))
        Text("Рецепт", modifier = Modifier.padding(top = 30.dp), color = Color.White)
        OutlinedTextField(
            value = gotov.value,
            onValueChange = { gotov.value = it },
            textStyle = TextStyle(
                color = Color.Black,
                fontSize = 15.sp
            ),
            colors = TextFieldDefaults.colors(
                focusedContainerColor = Color(0XFFF5F5F9),
                focusedIndicatorColor = Color(0xFFEBEBEB),
                focusedTextColor = background,
                disabledIndicatorColor = Color.Transparent,
                unfocusedIndicatorColor = Color.Transparent,
                cursorColor = background,
            ),
            modifier = Modifier
                .fillMaxWidth(0.7f)
                .width(width = 316.dp)
        )
        Spacer(Modifier.width(100.dp))
        Column(
            modifier = Modifier
                .fillMaxSize()
                .background(background)
                .padding(top = 50.dp),
            horizontalAlignment = Alignment.CenterHorizontally
        )
        {
            Button(
                onClick = {
                    viewModel.AddDishesBlog(
                        name.value,
                        decr.value,
                        gotov.value,
                    )
                    flag.value = true
                },
                modifier = Modifier
                    .fillMaxWidth(0.5f)
                    .height(50.dp),
                shape = RoundedCornerShape(20),
                colors = ButtonColors(
                    contentColor = Color.White,
                    containerColor = Color(0xFF7DAD01),
                    disabledContentColor = Color.White,
                    disabledContainerColor = Color(0xFF7DAD01)
                )
            ) {
                Text(text = "Добавить", fontSize = 20.sp, fontWeight = FontWeight.Light)
            }
            Column(modifier = Modifier
                .fillMaxSize()
                .background(background)
                .padding(top = 50.dp),
                horizontalAlignment = Alignment.CenterHorizontally) {
                Button(
                    onClick = {
                        navController.popBackStack()
                    },
                    modifier = Modifier
                        .fillMaxWidth(0.5f)
                        .height(50.dp),
                    shape = RoundedCornerShape(20),
                    colors = ButtonColors(
                        contentColor = Color.White,
                        containerColor = Color(0xFF7DAD01),
                        disabledContentColor = Color.White,
                        disabledContainerColor = Color(0xFF7DAD01)
                    )
                ) {
                    Text(text = "Назад", fontSize = 20.sp, fontWeight = FontWeight.Light)
                }
            }
        }
    }
    if (flag.value) {
        when (userState) {
            is UserState.Loading -> {
                Box(Modifier.fillMaxSize(), contentAlignment = Alignment.Center) {
                    CircularProgressIndicator()
                }
            }

            is UserState.Success -> {
                viewModel.allDishesBlog()
                navController.popBackStack()
                flag.value = false
            }

            is UserState.Error -> {
                val message = (userState as UserState.Error).message
                Toast.makeText(context, message, Toast.LENGTH_SHORT).show()
                flag.value = false
            }
        }
    }
}