package com.example.osnov_android.views

import android.widget.Space
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ExperimentalMaterial3Api
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp

data class FAQItem(val question: String, val answer: String)

@Composable
fun Faq() {
    val faqList = listOf(
        FAQItem("Как восстановить пароль?", "Вы можете восстановить пароль через раздел 'Забыли пароль?' на экране входа."),
        FAQItem("Как изменить настройки профиля?", "Настройки профиля можно изменить в разделе 'Профиль', нажав на кнопку 'Изменить'."),
        FAQItem("Как связаться с поддержкой?", "Связаться с поддержкой довольно просто, напишите ваше обращение на почту 'foodexpertfaq@mail.ru', мы постораемя в ближайшее время ответить."),
        FAQItem("Остались вопросы?", "Напишите ваш вопрос на почту 'foodexpertfaq@mail.ru' или по номеру телефона '+75645645674' в Whatsup."),
    )
    val background = Color(0xFF1B1A20)



    Column(modifier = Modifier
        .fillMaxSize()
        .background(background))
        {

            Column(
                modifier = Modifier
                    .fillMaxSize()
                    .background(background)
                    .padding(top = 50.dp),
                horizontalAlignment = Alignment.CenterHorizontally
            ) {
                Text(
                    text = "FAQ",
                    fontWeight = FontWeight.Light,
                    fontSize = 24.sp,
                    color = Color(0xFFFFFFFF),
                    letterSpacing = 10.sp
                )
                Spacer(modifier = Modifier.height(50.dp))

                Text(
                    text = "Часто задаваемые вопросы",
                    style = MaterialTheme.typography.titleLarge,
                    modifier = Modifier.padding(bottom = 16.dp),
                    color = Color.White
                )

                faqList.forEach { faqItem ->
                    FAQItemView(faqItem)
                }
            }
    }
}

@Composable
fun FAQItemView(faqItem: FAQItem) {
    var isExpanded by remember { mutableStateOf(false) }


    Column(modifier = Modifier
        .fillMaxWidth(0.7f)
        .padding(vertical = 8.dp)
        .clickable { isExpanded = !isExpanded }
        .background(MaterialTheme.colorScheme.primaryContainer, RoundedCornerShape(8.dp))
        .padding(16.dp)) {

        Text(
            text = faqItem.question,
            style = MaterialTheme.typography.bodyLarge,
            fontSize = 18.sp
        )

        if (isExpanded) {
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = faqItem.answer,
                style = MaterialTheme.typography.bodyMedium,
                fontSize = 16.sp
            )
        }
    }
}

@OptIn(ExperimentalMaterial3Api::class)
@Composable
fun MyApp() {
    MaterialTheme {
        Faq()
    }
}
